package net.jaekl.cfb.db;

// Copyright (C) 2015 Christian Jaekl

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;

public class Table {
	String m_name;
	HashMap<String, Column> m_columnsByName;
	ArrayList<Column> m_columns;
	
	public Table(String name, Column[] columns) {
		m_name = name;

		m_columns = new ArrayList<Column>();
		m_columns.addAll(Arrays.asList(columns));

		m_columnsByName = new HashMap<String, Column>();
		for (int i = 0; i < columns.length; ++i) {
			m_columnsByName.put(columns[i].getName(), columns[i]);
		}
	}
	
	public String getName() { return m_name; }
	public int getNumColumns() { return m_columns.size(); }
	public Column getColumn(int idx) { return m_columns.get(idx); }
	public Column getColumn(String name) { return m_columnsByName.get(name); }
	
	// Construct a table from an array of objects like this:
	// {
	//   { table_name },
	//   { column_name, type, width (-1 for default), null/not_null }
	// }
	public static Table construct(Object[][] spec) 
	{
		assert(null != spec);
		assert(spec.length > 1);
		assert(1 == spec[0].length);
		assert(spec[0][0] instanceof String);
		
		String name = (String)(spec[0][0]);
		Column[] columns = new Column[spec.length - 1];
		
		for (int idx = 1; idx < spec.length; ++idx) {
			columns[idx - 1] = Column.construct(spec[idx]);
		}
		
		return new Table(name, columns);
	}
}
